Crate phase_sqs

Crate phase_sqs 

Structs

SqsClient
Represents a client that interacts with AWS SQS. The client is responsible for sending and consuming messages from an SQS queue.

Traits

MessageProcessor
A trait that defines how to process messages from the SQS queue.